@@ -413,13 +413,40 @@ class Experimento:
 
         print(self.matriz_cuadriculada)
 
+    def calcula_matrices_solo_regiones_preferidas(self, regiones_preferidas):
+
+        print("Se inicia el procesamiento de las matrices con regiones preferidas")
+
+        self.regiones_preferidas = regiones_preferidas
+        total_regiones = list(range(0, self.cantidad_columnas * self.cantidad_filas))
+        self.regiones_no_preferidas = m_reg_pref.obtener_complemento_de_sublista(lista=total_regiones,
+                                                                                 sublista=regiones_preferidas)
+
+        print("Regiones preferidas: ", self.regiones_preferidas)
+        print("Regiones no preferidas: ", self.regiones_no_preferidas)
+
+        print("--------------------------------------------------------------------------------")
+
+        matriz_cuadriculada = np.flipud(self.matriz_cuadriculada)
+        print("Se toma matriz cuadriculada", matriz_cuadriculada)
+
+        self.matriz_cuadriculada_solo_regiones_preferidas = \
+            m_reg_pref.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_preferidas)
+        self.matriz_cuadriculada_solo_regiones_preferidas = \
+            np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
+
+        self.matriz_cuadriculada_solo_regiones_no_preferidas = \
+            m_reg_pref.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_no_preferidas)
+        self.matriz_cuadriculada_solo_regiones_no_preferidas = \
+            np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
+
     def calcula_entropias_regiones_cuadriculadas(self):
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="visitas_regiones",
                                        datos=self.matriz_cuadriculada.flatten())
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="visitas_regiones_preferidas",
-                                       datos=self.matriz_cuadriculada_regiones_preferidas.flatten())
+                                       datos=self.matriz_cuadriculada_solo_regiones_preferidas.flatten())
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="visitas_regiones_no_preferidas",
                                        datos=self.matriz_cuadriculada_solo_regiones_no_preferidas.flatten())
@@ -458,33 +485,6 @@ class Experimento:
             m_recurr.calcula_matrices_de_recurrencia(self.arreglo_region_cuadriculada,
                                                      region_importante=lista_indices)
 
-    def calcula_matrices_solo_regiones_preferidas(self, regiones_preferidas):
-
-        print("Se inicia el procesamiento de las matrices con regiones preferidas")
-
-        self.regiones_preferidas = regiones_preferidas
-        total_regiones = list(range(0, self.cantidad_columnas * self.cantidad_filas))
-        self.regiones_no_preferidas = m_reg_pref.obtener_complemento_de_sublista(lista=total_regiones,
-                                                                                 sublista=regiones_preferidas)
-
-        print("Regiones preferidas: ", self.regiones_preferidas)
-        print("Regiones no preferidas: ", self.regiones_no_preferidas)
-
-        print("--------------------------------------------------------------------------------")
-
-        matriz_cuadriculada = np.flipud(self.matriz_cuadriculada)
-        print("Se toma matriz cuadriculada", matriz_cuadriculada)
-
-        self.matriz_cuadriculada_solo_regiones_preferidas = \
-            m_reg_pref.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_preferidas)
-        self.matriz_cuadriculada_solo_regiones_preferidas = \
-            np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
-
-        self.matriz_cuadriculada_solo_regiones_no_preferidas = \
-            m_reg_pref.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_no_preferidas)
-        self.matriz_cuadriculada_solo_regiones_no_preferidas = \
-            np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
-
     def calcula_arreglos_rutas_vectoriales(self,
                                            tamanio_vectorial,
                                            brinco_temporal,
