@@ -68,9 +68,17 @@ class MultiplesExperimentos:
                                                 )
                 self.lista_experimentos.append(nuevo_experimento)
 
-    def calcula_velocidades_multiples_experimentos(self):
+    def calcula_velocidades_aceleraciones(self):
         for experimento in self.lista_experimentos:
-            experimento.calcula_velocidades()
+            experimento.calcula_velocidad_aceleracion()
+
+    def agrega_histogramas_vel_acel(self):
+        for experimento in self.lista_experimentos:
+            experimento.agrega_histogramas_vel_acel()
+
+    def agrega_entropias_histogramas_vel_acel(self):
+        for experimento in self.lista_experimentos:
+            experimento.agrega_entropias_histogramas_vel_acel()
 
     def calcula_regiones_cuadriculadas(self,
                                        arreglo_regiones_preferidas):
@@ -78,9 +86,9 @@ class MultiplesExperimentos:
             experimento.calcula_regiones_cuadriculadas()
             experimento.calcula_matrices_solo_regiones_preferidas(regiones_preferidas=arreglo_regiones_preferidas)
 
-    def calcula_entropias_divergencias(self):
+    def agrega_entropias_regiones_cuadriculadas(self):
         for experimento in self.lista_experimentos:
-            experimento.calcula_entropias()
+            experimento.calcula_entropias_regiones_cuadriculadas()
 
     def calcula_entropias_aproximadas(self,
                                       tamanio_vectores=2,
